@@ -146,3 +146,17 @@ it("should respect isModule = true", async () => {
     );
     expect(f).toThrowError(`failed to parse module: error was recoverable, but proceeding would result in wrong codegen`)
 });
+
+
+
+it("should respect `inlineSourcesContent`", async () => {
+    const src = '/* Comment */import foo, {bar} from "foo"';
+    const { map } = await swc.transform(src, {
+        sourceMaps: true,
+        inlineSourcesContent: true,
+    });
+
+    const j = JSON.parse(map);
+
+    expect(j).toHaveProperty('sourcesContent')
+});
\ No newline at end of file
