@@ -1,5 +1,5 @@
 function Component() {
     return(/*#__PURE__*/ React.createElement("div", {
-        name: "A\\n\\n      B"
+        name: "A B"
     }));
 }
