@@ -113,7 +113,7 @@ fn issue_706() {
     inline("tests/srcmap/issue-706/index.js").unwrap();
 }
 
-#[cfg(target_os = "node-16-breaks-the-test")]
+#[cfg(feature = "node14-test")]
 #[testing::fixture("stacktrace/**/input/")]
 fn stacktrace(input_dir: PathBuf) {
     let dir = input_dir.parent().unwrap();
@@ -123,7 +123,7 @@ fn stacktrace(input_dir: PathBuf) {
 
     Tester::new()
         .print_errors(|cm, handler| {
-            let c = Compiler::new(cm.clone(), Arc::new(handler));
+            let c = Compiler::new(cm.clone());
 
             for entry in WalkDir::new(&input_dir) {
                 let entry = entry.unwrap();
@@ -142,6 +142,7 @@ fn stacktrace(input_dir: PathBuf) {
 
                 match c.process_js_file(
                     fm,
+                    &handler,
                     &Options {
                         swcrc: true,
                         is_module: true,
